@@ -96,14 +96,9 @@ class Cmd4Platform
 
 
       // Defaults before parse
-      this.restartRecover = true;
       this.outputConstants = constants.DEFAULT_OUTPUTCONSTANTS;
       this.statusMsg = constants.DEFAULT_STATUSMSG;
 
-      // Every X polls, output the queue status information.
-      this.queueStatMsgInterval = constants.DEFAULT_QUEUE_STAT_MSG_INTERVAL;
-      this.queueMsg = constants.DEFAULT_QUEUEMSG;
-
       // Track the polling timers only so that unit testing can cancel them.
       this.pollingTimers = [ ];
 
@@ -118,14 +113,6 @@ class Cmd4Platform
       {
          this.log.info( chalk.blue( "Cmd4Platform didFinishLaunching" ) );
 
-         if ( this.restartRecover == false &&
-              this.toBeRestoredPlatforms.length > 0  )
-         {
-            this.log.info( chalk.yellow( `Removing ` ) + chalk.red( `*ALL* ` ) + chalk.yellow( `cached accessories as: ${ constants.RESTART_RECOVER } is set to false` ) );
-            this.api.unregisterPlatformAccessories(  settings.PLUGIN_NAME, settings.PLATFORM_NAME, this.toBeRestoredPlatforms );
-            this.toBeRestoredPlatforms = [ ];
-         }
-
          this.discoverDevices( this.log );
 
          // Any accessory not reachable must have been removed, find them
@@ -238,54 +225,43 @@ class Cmd4Platform
                this.outputConstants = value;
 
                break;
-            case constants.RESTART_RECOVER:
-               this.restartRecover = value;
-
+            case "RestartRecover":
+               this.log.warn( `Warning: ${ key } has been deprecated. Not having restart recovery could mean your device would turn on/off over a restart; Therefore ${ key } is now always enabled.` );
+               this.log.warn( `To remove this message, just remove ${ key } from your config.json` );
                break;
             case constants.STATUSMSG:
               if ( value === false )
                  this.statusMsg = "FALSE";
 
                break;
-            case constants.QUEUE_STAT_MSG_INTERVAL:
-               this.queueStatMsgInterval = value;
+            case "QueueStatMsgInterval":
+
+               // Never put into production
+               this.log.warn( `Warning: ${ key } has been deprecated. It was never even used.` );
+               this.log.warn( `To remove this message, just remove ${ key } from your config.json` );
 
                break;
-            case constants.QUEUEMSG:
-               this.queueMsg = value;
+            case "QueueMsg":
+
+               // Never put into production
+               this.log.warn( `Warning: ${ key } has been deprecated. It was never even used.` );
+               this.log.warn( `To remove this message, just remove ${ key } from your config.json` );
 
                break;
             case constants.QUEUETYPES:
-               parseAddQueueTypes( this.log, value,
-                  { [ constants.QUEUE_STAT_MSG_INTERVAL_lv ]: this.queueStatMsgInterval,
-                    [ constants.QUEUEMSG_lv ]: this.queueMsg } );
+               parseAddQueueTypes( this.log, value );
 
                break;
-            case constants.FETCH:
-               this.log.warn( `Warning: ${ constants.FETCH }:${ value } is changing to ${ constants.CMD4_MODE }:${ value } to reflect its affect on both Set and Get.` );
-               this.log.warn( `To remove this message, change to ${ constants.CMD4_MODE }` );
-
-               // break omitted
-            case constants.CMD4_MODE:
-               switch( value )
+            case "Cmd4_Mode":
+               this.log.warn( `Warning: ${ key } has been deprecated.` );
+               if ( value == "Demo" )
                {
-                  case constants.CMD4_MODE_CACHED:
-                     this.log.warn( `Warning: ${ constants.CMD4_MODE_CACHED } is changing to ${ constants.CMD4_MODE_DEMO } as it should only be used for demonstartion with no state_cmd needed.` );
-                     this.log.warn( `To remove this message, change to ${ constants.CMD4_MODE_DEMO }` );
-                     // break omitted
-                  case constants.CMD4_MODE_DEMO:
-                  case constants.CMD4_MODE_ALWAYS:
-                  case constants.CMD4_MODE_POLLED:
-                  case constants.CMD4_MODE_FULLYPOLLED:
-
-                     this.cmd4Mode = value;
-
-                     break;
-                  default:
-                     this.log.error( chalk.red( `Invalid value: ${ value } for ${ constants.CMD4_MODE }` ) );
-                     this.log.error( `Must be: [ ${ constants.CMD4_MODE_DEMO } | ${ constants.CMD4_MODE_ALWAYS } | ${ constants.CMD4_MODE_POLLED } | ${ constants.MODE_FULLYPOLLED }` );
-                     process.exit( 261 ) ;
+                  this.log.warn( `Demo mode is achieved when there is not any polling entries in your config.json.` );
+               } else
+               {
+                  this.log.warn( `Cmd4 has been simplified and optimized as per: https://git.io/JtMGR.` );
                }
+               this.log.warn( `To remove this message, just remove "${ key }" from your config.json` );
                break;
             case constants.STORAGE:
                if ( value == constants.FS_l || value == constants.GOOGLEDRIVE_l )
@@ -760,62 +736,13 @@ class Cmd4Platform
       cmd4PlatformAccessory.setupAccessoryFakeGatoService( cmd4PlatformAccessory.fakegatoConfig );
    }
 
-   startStaggeredPolling( staggeredPollingArray )
-   {
-      let delay = 0;
-      let staggeredDelays = [ 3000, 6000, 9000, 12000 ];
-      let staggeredDelaysLength = staggeredDelays.length;
-      let staggeredDelayIndex = 0;
-      let lastAccessoryUUID = ""
-
-      staggeredPollingArray.forEach( ( entry, entryIndex )  =>
-      {
-         setTimeout( ( ) =>
-         {
-            if ( entryIndex == 0 )
-               entry.accessory.log.info( `Started staggered kick off of ${ staggeredPollingArray.length } polled characteristics` );
-
-            if ( cmd4Dbg ) entry.accessory.log.debug( `Kicking off polling for: ${ entry.accessory.displayName } ${ entry.characteristicString } interval:${ entry.interval }, staggered:${ staggeredDelays[ staggeredDelayIndex ] }` );
-            entry.accessory.listOfRunningPolls[ entry.accessory.displayName + entry.accTypeEnumIndex ] =
-               setTimeout( entry.accessory.characteristicPolling.bind(
-                  entry.accessory, entry.accessory, entry.accTypeEnumIndex, entry.characteristicString, entry.timeout, entry.interval ), entry.interval );
-
-            if ( entryIndex == settings.arrayOfAllStaggeredPollingCharacteristics.length -1 )
-               entry.accessory.log.info( `All characteristics are now being polled` );
-
-         }, delay );
-
-
-         if ( staggeredDelayIndex++ >= staggeredDelaysLength )
-            staggeredDelayIndex = 0;
-
-         if ( lastAccessoryUUID != entry.accessory.UUID )
-            staggeredDelayIndex = 0;
-
-         lastAccessoryUUID = entry.accessory.UUID;
-
-         delay += staggeredDelays[ staggeredDelayIndex ];
-
-      });
-   }
-
    // The delay definitions are not meant to be changed, except for unit testing
    // ==========================================================================
    // staggeredStartDelay - These would be for just polling and to be nice to the system.
    // queuedStartDelay - As this is both IOS and polling, the delay only happens to 
    // the low priority polling.
-   startPolling( staggeredStartDelay = 30000, queuedStartDelay = 40000 )
+   startPolling( queuedStartDelay = 40000 )
    {
-      if ( settings.arrayOfAllStaggeredPollingCharacteristics.length > 0 )
-      {
-         let pollingTimer = setTimeout( ( ) =>
-         {
-            this.startStaggeredPolling( settings.arrayOfAllStaggeredPollingCharacteristics );
-         }, staggeredStartDelay );
-
-         this.pollingTimers.push( pollingTimer );
-      }
-
       // Check for any queued characteristics
       if ( Object.keys( settings.listOfCreatedPriorityQueues ).length == 0 )
       {
@@ -824,13 +751,20 @@ class Cmd4Platform
       }
 
       // Start polling of each queue of characteristics
-      Object.keys( settings.listOfCreatedPriorityQueues ).forEach( ( queueName ) =>
+      let lastIndex = Object.keys( settings.listOfCreatedPriorityQueues ).length;
+      Object.keys( settings.listOfCreatedPriorityQueues ).forEach( ( queueName, index ) =>
       {
          let queue = settings.listOfCreatedPriorityQueues[ queueName ];
          let queuedPollingTimer = setTimeout( ( ) =>
          {
-            this.log.info( ` *** Starting Priority Polling Queue "${ queue.queueName }"` );
-            queue.startQueue( queue );
+            if ( index == lastIndex -1 )
+              this.log.info( chalk.magenta( `*** Starting Polling` ) );
+            queue.startQueue( queue, ( ) =>
+            {
+               if ( index == 0 )
+                  this.log.info( chalk.magenta( `*** All characteristics are now being polled` ) );
+            });
+
          }, queuedStartDelay );
 
          this.pollingTimers.push( queuedPollingTimer );
