@@ -18,18 +18,13 @@ exports.FAST_STATE_CHANGE_RESPONSE_TIME      = 1000;   // 1 second
 
 exports.DEFAULT_TIMEOUT          = 60000; // 1 minute
 exports.DEFAULT_INTERVAL         = 60000; // 1 minute
-exports.DEFAULT_QUEUE_INTERVAL   = 60000; // 1 minute
 
 // Not a Bool, otherwise conditional check fails
 exports.DEFAULT_STATUSMSG        = "TRUE";
 
 exports.DEFAULT_OUTPUTCONSTANTS  = false;
-exports.DEFAULT_QUEUEMSG         = false;
 exports.DEFAULT_QUEUE_TYPE       = "WoRm";
-exports.DEFAULT_RECOVERY_TIMER_INTERVAL   = 60000; // 1 minute
-
-// How many polls before output of queue status information
-exports.DEFAULT_QUEUE_STAT_MSG_INTERVAL = 1000;
+exports.DEFAULT_QUEUE_PAUSE_TIMEOUT = 10000; // 10 seconds
 
 
 // Fakegato Constants
@@ -77,14 +72,17 @@ exports.GOOGLE_DRIVE_l           = "googleDrive";
 exports.DEBUG                    = "Debug";
 exports.DEBUG_l                  = "debug";
 exports.OUTPUTCONSTANTS          = "OutputConstants";
-exports.RESTART_RECOVER          = "RestartRecover";
 exports.STATUSMSG                = "StatusMsg";
-exports.QUEUEMSG                 = "QueueMsg";
 exports.QUEUETYPE                = "QueueType";
 exports.QUEUETYPES               = "QueueTypes";
+
+// Queue Types
 exports.QUEUETYPE_SEQUENTIAL     = "Sequential";
-exports.QUEUE_INTERVAL           = "QueueInterval";
 exports.QUEUETYPE_WORM           = "WoRm";
+// Used internally to mean only polled entries go straight through the queue
+exports.QUEUETYPE_STANDARD       = "StandarD";
+// Used internally to mean entries go straight through the queue
+exports.QUEUETYPE_PASSTHRU       = "None";
 
 
 // Platform Config Constnts
@@ -103,16 +101,7 @@ exports.FIRMWAREREVISION         = "FirmwareRevision";
 exports.CHARACTERISTIC           = "Characteristic";
 exports.TIMEOUT                  = "Timeout";
 exports.QUEUE                    = "Queue";
-exports.DEFAULT_QUEUE_NAME       = "No_Queue";
-exports.QUEUE_STAT_MSG_INTERVAL  = "QueueStatMsgInterval";
 exports.POLLING                  = "Polling";
-exports.CMD4_MODE_ALWAYS         = "Always";
-exports.CMD4_MODE_CACHED         = "Cached";  // CACHED becomes DEMO
-exports.CMD4_MODE_DEMO           = "Demo";
-exports.CMD4_MODE_POLLED         = "Polled";
-exports.CMD4_MODE_FULLYPOLLED    = "FullyPolled";
-exports.FETCH                    = "Fetch";
-exports.CMD4_MODE                = "Cmd4_Mode";
 exports.INTERVAL                 = "Interval";
 exports.STATECHANGERESPONSETIME  = "StateChangeResponseTime";
 exports.STATE_CMD_PREFIX         = "State_cmd_prefix";
@@ -140,8 +129,6 @@ exports.INTERVAL_lv                    = "interval";
 exports.IS_SET_lv                      = "isSet";
 exports.QUEUE_NAME_lv                  = "queueName";
 exports.QUEUE_GET_IS_UPDATE_lv         = "queueGetIsUpdate";
-exports.QUEUEMSG_lv                    = "queueMsg";
-exports.QUEUE_STAT_MSG_INTERVAL_lv     = "queueStatMsgInterval";
 exports.RC_lv                          = "rc";
 exports.STATE_CHANGE_RESPONSE_TIME_lv  = "stateChangeResponseTime";
 exports.TIMEOUT_lv                     = "timeout";
@@ -149,7 +136,7 @@ exports.VALUE_lv                       = "value";
 exports.STORED_VALUES_PER_CHARACTERISTIC_lv = "storedValuesPerCharacteristic";
 
 exports.ERROR_TIMER_EXPIRED           = -151;
-exports.ERROR_CMD_FAILED_REPLY        = -152;
+//Exports.ERROR_CMD_FAILED_REPLY        = -152;
 exports.ERROR_NULL_REPLY              = -153;
 exports.ERROR_NULL_STRING_REPLY       = -154;
 exports.ERROR_EMPTY_STRING_REPLY      = -155;
